@@ -460,7 +460,7 @@
 #' @export
 ggpredict <- function(model,
                       terms,
-                      ci.lvl = .95,
+                      ci.lvl = 0.95,
                       type = "fe",
                       typical = "mean",
                       condition = NULL,
@@ -680,7 +680,14 @@ ggpredict_helper <- function(model,
 
   # check if outcome is log-transformed, and if so,
   # back-transform predicted values to response scale
-  result <- .back_transform_response(model, result, back.transform, verbose)
+  # but first, save original predicted values, to save as attribute
+  if (back.transform) {
+    untransformed.predictions <- result$predicted
+    response.transform <- insight::find_terms(model)[["response"]]
+  } else {
+    untransformed.predictions <- response.transform <- NULL
+  }
+  result <- .back_transform_response(model, result, back.transform, verbose = verbose)
 
   # add raw data as well
   attr(result, "rawdata") <- .get_raw_data(model, original_model_frame, terms)
@@ -700,6 +707,9 @@ ggpredict_helper <- function(model,
       condition = condition, show_pretty_message = FALSE, emmeans.only = TRUE
     ),
     condition = condition,
-    ci.lvl = ci.lvl
+    ci.lvl = ci.lvl,
+    untransformed.predictions = untransformed.predictions,
+    back.transform = back.transform,
+    response.transform = response.transform
   )
 }
