@@ -22,10 +22,11 @@
   at_levels <- lapply(strsplit(at_levels, ",", fixed = TRUE), trimws)
 
   # moderator pattern
-  at_pattern <- c("minmax", "meansd", "zeromax", "quart2", "all", "quart")
+  at_pattern <- c("minmax", "meansd", "zeromax", "quart2", "all", "quart",
+                  "fivenum", "terciles", "terciles2", "quartiles", "quartiles2")
 
   # now check for ranges
-  at_levels <- mapply(function(x, y) {
+  at_levels <- Map(function(x, y) {
 
     # Here we may have a range of values. we then create the
     # sequence with all values from this range
@@ -51,14 +52,14 @@
 
       # values at pretty range -----------------------------------------------
 
-      steps <- as.numeric(trimws(substring(gsub(" ", "", x), first = 3)))
+      steps <- as.numeric(trimws(substring(gsub(" ", "", x, fixed = TRUE), first = 3)))
       x <- pretty_range(model_frame[[y]], n = steps)
 
     } else if (length(x) == 1 && grepl("^sample(\\s*)=", x)) {
 
       # values at random samples ---------------------------------------------
 
-      size <- as.numeric(trimws(substring(gsub(" ", "", x), first = 8)))
+      size <- as.numeric(trimws(substring(gsub(" ", "", x, fixed = TRUE), first = 8)))
       lev <- stats::na.omit(unique(model_frame[[y]]))
       pos <- sample.int(n = length(lev), size = size, replace = FALSE)
       x <- lev[pos]
@@ -100,29 +101,25 @@
 
           # return values of a vector
         } else {
-          x <- tryCatch({
-            get(x, envir = parent.frame())
-          }, error = function(e) {
-            NULL
-          })
-          if (is.null(x)) {
-            x <- tryCatch({
-              get(x, envir = globalenv())
-            }, error = function(e) {
-              NULL
-            })
+          out <- .safe(get(x, envir = parent.frame()))
+          if (is.null(out)) {
+            out <- .safe(get(x, envir = globalenv()))
           }
+          if (is.null(out)) {
+            out <- .safe(dynGet(x, ifnotfound = NULL))
+          }
+          x <- out
         }
       }
     }
 
     x
-  }, at_levels, at_terms, SIMPLIFY = FALSE)
+  }, at_levels, at_terms)
 
   # check if levels were numeric or not...
   suppressWarnings(
     if (!anyNA(unlist(lapply(at_levels, as.numeric)))) {
-      at_levels <- lapply(at_levels, function(i) stats::setNames(as.numeric(i), names(i)))
+      at_levels <- lapply(at_levels, as.numeric)
     }
   )
 
