@@ -1,4 +1,3 @@
-#' @importFrom insight model_info is_multivariate
 .get_model_function <- function(model) {
   # check class of fitted model
 
@@ -27,7 +26,12 @@
 
 get_predict_function <- function(model) {
   if (inherits(model, c("wblm", "wbm"))) return("wbm")
+  else if (inherits(model, c("phylolm", "phyloglm"))) return("phylolm")
+  else if (inherits(model, "mblogit")) return("mblogit")
   else if (inherits(model, "mclogit")) return("mclogit")
+  else if (inherits(model, "logitr")) return("logitr")
+  else if (inherits(model, "averaging")) return("averaging")
+  else if (inherits(model, "orm")) return("orm")
   else if (inherits(model, "mlogit")) return("mlogit")
   else if (inherits(model, "glimML")) return("glimML")
   else if (inherits(model, "cgam")) return("cgam")
