@@ -39,13 +39,12 @@
 #' vcov(result)
 #' @export
 vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args = NULL, ...) {
-  model <- tryCatch(get(attr(object, "model.name"), envir = parent.frame()),
-                    error = function(e) NULL)
+  model <- .safe(get(attr(object, "model.name"), envir = parent.frame()))
 
   if (is.null(model)) {
-    warning(insight::format_message(
+    insight::format_warning(
       "Can't access original model to compute variance-covariance matrix of predictions."
-    ), call. = FALSE)
+    )
     return(NULL)
   }
 
@@ -143,9 +142,9 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
       )
     },
     error = function(e) {
-      message(insight::format_message(
+      insight::format_alert(
         "Could not compute variance-covariance matrix of predictions. No confidence intervals are returned."
-      ))
+      )
       NULL
     }
   )
@@ -157,7 +156,7 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
   # check if robust vcov-matrix is requested
   if (!is.null(vcov.fun)) {
     # check for existing vcov-prefix
-    if (!grepl("^vcov", vcov.fun)) {
+    if (!startsWith(vcov.fun, "vcov")) {
       vcov.fun <- paste0("vcov", vcov.fun)
     }
     # set default for clubSandwich
@@ -182,7 +181,7 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
     }
   } else {
     # get variance-covariance-matrix, depending on model type
-    vcm <- insight::get_varcov(model, component = "conditional")
+    vcm <- suppressMessages(insight::get_varcov(model, component = "conditional"))
   }
 
 
@@ -259,7 +258,7 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
     contrs <- contrs[keep.c]
     terms <- terms[!rem.t]
 
-    add.terms <- unlist(mapply(function(.x, .y) {
+    add.terms <- unlist(Map(function(.x, .y) {
       f <- model_frame[[.y]]
       if (!is.factor(f)) {
         f <- as.factor(f)
@@ -270,7 +269,7 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
         sprintf("%s%s", .y, c(".L", ".Q", ".C"))
       else
         sprintf("%s%s", .y, levels(f)[2:nlevels(f)])
-    }, contrs, names(contrs), SIMPLIFY = FALSE))
+    }, contrs, names(contrs)))
 
     terms <- c(terms, add.terms)
   }
@@ -282,6 +281,12 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
   # matrix for which terms we need standard errors.
 
   model_matrix_data <- as.data.frame(mm)
+
+  # we may have backticks in our model matrix, so remove those from column names
+  if (any(startsWith(colnames(model_matrix_data), "`"))) {
+    colnames(model_matrix_data) <- gsub("^`(.*)`$", "\\1", colnames(model_matrix_data))
+  }
+
   rows_to_keep <- as.numeric(rownames(unique(model_matrix_data[intersect(colnames(model_matrix_data), terms)])))
 
   # for poly-terms, we have no match, so fix this here
