@@ -9,6 +9,8 @@ if (.runThisTest && getRversion() >= "3.6.0") {
     test_that("ggpredict", {
       p <- ggpredict(m1, "temp")
       expect_equal(p$predicted[1], 0.1960351, tolerance = 1e-3)
+      expect_equal(p$conf.low[1], 0.0772626, tolerance = 1e-3)
+      expect_equal(p$conf.high[1], 0.41522921, tolerance = 1e-3)
       ggpredict(m1, c("temp", "contact"))
     })
 
