@@ -1,11 +1,9 @@
 if (suppressWarnings(
-  require("testthat") &&
-  require("ggeffects") &&
-  require("sjmisc") &&
-  require("MASS")
+  requiet("testthat") &&
+  requiet("ggeffects") &&
+  requiet("sjmisc") &&
+  requiet("MASS")
 )) {
-  context("ggeffects, negbin model")
-
   data(efc)
   efc$e42dep <- to_label(efc$e42dep)
   fit <-
@@ -17,12 +15,12 @@ if (suppressWarnings(
     )
 
   test_that("ggpredict, negbin", {
-    ggpredict(fit, "neg_c_7")
-    ggeffect(fit, "neg_c_7")
+    expect_s3_class(ggpredict(fit, "neg_c_7"), "data.frame")
+    expect_s3_class(ggeffect(fit, "neg_c_7"), "data.frame")
     # still fails on windows old-rel, so re-activate once emmeans is built on all platforms
     # expect_null(ggemmeans(fit, "neg_c_7"))
-    ggpredict(fit, c("neg_c_7", "e42dep"))
-    ggeffect(fit, c("neg_c_7", "e42dep"))
+    expect_s3_class(ggpredict(fit, c("neg_c_7", "e42dep")), "data.frame")
+    expect_s3_class(ggeffect(fit, c("neg_c_7", "e42dep")), "data.frame")
     # expect_null(ggemmeans(fit, c("neg_c_7", "e42dep")))
   })
 
@@ -36,11 +34,11 @@ if (suppressWarnings(
     )
 
   test_that("ggpredict, negbin", {
-    ggpredict(fit, "neg_c_7")
-    ggeffect(fit, "neg_c_7")
+    expect_s3_class(ggpredict(fit, "neg_c_7"), "data.frame")
+    expect_s3_class(ggeffect(fit, "neg_c_7"), "data.frame")
     # expect_null(ggemmeans(fit, "neg_c_7"))
-    ggpredict(fit, c("neg_c_7", "e42dep"))
-    ggeffect(fit, c("neg_c_7", "e42dep"))
+    expect_s3_class(ggpredict(fit, c("neg_c_7", "e42dep")), "data.frame")
+    expect_s3_class(ggeffect(fit, c("neg_c_7", "e42dep")), "data.frame")
     # expect_null(ggemmeans(fit, c("neg_c_7", "e42dep")))
   })
 }
